# linuk
Python Utility library for faster coding.

# Installation
    
    pip install linuk


# Example
    
    from linuk.basic import listmaker
    listmaker('ab cd ef gh')
    
## for more documentation use built in help() command.
    
    